@@ -34,8 +34,7 @@ def on_MDML_connect(client, userdata, flags, rc):
     if rc == 5:
         print("ERROR! Broker connection was refused. This may be caused by an incorrect username or password.")
         client.loop_stop(force=True)
-    # print("MDML_DEBUG/"+userdata)
-    # client.subscribe("MDML_DEBUG/"+userdata)
+    print("\nConnected!\n")
 
 def unix_time(ret_int=False):
     """
@@ -216,7 +215,7 @@ class experiment:
         except ConnectionRefusedError:
             print("ERROR! Broker connection was refused. This may be caused by an incorrect username or password.")
         except:
-            print("ERROR! Could not connect to the MDML's message broker. Verify you have the correct host. Contact jelias@anl.gov if the problem persists.")
+            print("ERROR! Could not connect to the MDML's message broker. Verify you have the correct host and can reach it on port 1883.")
 
         if s3_access_key is not None:
             # Creating boto3 (s3) client connection
@@ -928,6 +927,7 @@ class experiment:
         except:
             print("File not found.")
             return
+        self.start_debugger()
         # Opening experiment tar file
         exp_tar = tarfile.open(filename)
         exp_tar.extractall()
